@@ -1,53 +1,32 @@
+import sqlite3 as _sql
 class _variables():
-	def __init__(self):
-		self.path=None
-		self.data={"server":{}, "global":{}, "user":{}}
-		self.vars={}
-	def save(self):
-		import json
-		if self.path is not None:
-			json.dump(self.data,open(self.path+"vars.json","w"))
-	def load(self):
-		import json
-		self.data={"server":{}, "global":{}, "user":{}}
-		if self.path is not None:
+	def __init__(self,conn,values):
+		self._conn=conn
+		self._cursor=conn.cursor()
+		valstr="id INT"
+		for var in values:
+			valstr+=",\n	"+var+" TEXT"
+		self._cursor.execute("""CREATE TABLE IF NOT EXISTS globals(
+		"""+valstr+"""
+		)""")
+		self._cursor.execute("""CREATE TABLE IF NOT EXISTS servers(
+		"""+valstr+"""
+		)""")
+		for var in values:
 			try:
-				self.data=json.load(open(self.path+"vars.json","r"))
+				self._cursor.execute(f"alter table globals add column '{var}' 'TEXT'")
 			except:
 				pass
-	def get(self,type,name,id,server=None):
-		try:
-			if type=="user":
-				if not str(server) in self.data[type]:
-					self.data[type][str(server)]={}
-				if not str(id) in self.data[type][str(server)]:
-					self.data[type][str(server)][str(id)]=self.vars
-				if not str(name) in self.data[type][str(server)][str(id)]:
-					self.data[type][str(server)][str(id)][name]=self.vars[name]
-				return self.data[type][str(server)][str(id)][name]
-			else:
-				if not str(id) in self.data[type]:
-					self.data[type][str(id)]=self.vars
-				if not str(name) in self.data[type][str(id)]:
-					self.data[type][str(id)][name]=self.vars[name]
-				return self.data[type][str(id)][name]
-		except Exception as e:
-			return "none"
-		
-	def set(self,type,name,data,id,server=None):
-		try:
-			if type=="user":
-				if not str(server) in self.data[type]:
-					self.data[type][str(server)]={}
-				if not str(id) in self.data[type][str(server)]:
-					self.data[type][str(server)][str(id)]=self.vars
-				self.data[type][str(server)][str(id)][name]=data
-			else:
-				if not str(id) in self.data[type]:
-					self.data[type][str(id)]=self.vars
-				self.data[type][str(id)][name]=data
-		except Exception as e:
-			pass
+			try:
+				self._cursor.execute(f"alter table servers add column '{var}' 'TEXT'")
+			except:
+				pass
+	def get(self,thing,type,where='11'):
+		self._cursor.execute(f'SELECT {thing} FROM {type} WHERE {where[0]} LIKE {where[1]}')
+		return self._cursor.fetchone()[0]
+	def set(self,things,type,where="11"):
+		self._cursor.execute(f"UPDATE {type} SET {things[0]}={things[1]} WHERE {where[0]} == {where[1]}")
+		self._conn.commit()
 
 class dbd_bot():
 	def __init__(self, info):
@@ -71,9 +50,9 @@ class dbd_bot():
 		self._codes["event"]={}
 		self._codes["command"]={}
 		self._cooldown={}
-		self._db=_variables()
 		self._cmds=[]
 		self._cs=0
+		self._vars={}
 		self._nowcmd=""
 		try:
 			self._debug=info["debug"]=="true"
@@ -83,6 +62,10 @@ class dbd_bot():
 			self._separator=info["sep"]
 		except:
 			self._separator=";"
+		try:
+			self._path=info["path"][:len(info["path"])-len(os.path.basename(info["path"]))]+"vars.db"
+		except Exception as e:
+			self._path="vars.db"
 		try:
 			self._self=info["self"]=="true"
 		except:
@@ -91,11 +74,6 @@ class dbd_bot():
 			self._help=info["help"]=="true"
 		except:
 			self._help=True
-		try:
-			self._db.path=info["path"].rstrip(os.path.basename(info["path"]))
-		except:
-			self._db.path=None
-		self._db.load()
 		try:
 			self._style=info["style"]
 		except:
@@ -139,12 +117,13 @@ class dbd_bot():
 		self._codes["event"][info["name"]]["code"]=code
 
 	def var(self, info):
-		self._db.vars[info["name"]]=info["value"]
+		self._vars[info["name"]]=info["value"]
 
 	def run(self):
 		for c in self._codes["command"]:
 			self._cmds.append(self._codes["command"][c]["name"])
 			self._cs+=1
+		self._db=_variables(_sql.connect(self._path),self._vars)
 		_start(self._client, self)
 
 def _start(client, bot):
@@ -216,40 +195,31 @@ def _start(client, bot):
 				break
 			else:
 				nowloop=line
-				try:
-					line=line.replace("$getVar"+bot._style[0]+line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],bot._db.get("global",line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0].split(qbot._separator)[0],line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]))
-				except:
+				if 0 <= 1 < len(line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)):
 					try:
-						line=line.replace("$getVar"+bot._style[0]+line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],bot._db.get("global",line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0].split(qbot._separator)[0],str(author.id)))
+						line=line.replace("$getVar"+bot._style[0]+line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],str(bot._db.get(line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0],"globals",["id",line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]])))
+					except Exception as e:
+						line=line.replace("$getVar"+bot._style[0]+line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],"none")
+				else:
+					try:
+						line=line.replace("$getVar"+bot._style[0]+line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],str(bot._db.get(line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0],"globals",["id",str(author.id)])))
 					except:
-						break
+						line=line.replace("$getVar"+bot._style[0]+line.split("$getVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],"none")
 		while "$getServerVar"+bot._style[0] in line:
 			if nowloop==line:
 				break
 			else:
 				nowloop=line
-				try:
-					line=line.replace("$getServerVar"+bot._style[0]+line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],bot._db.get("server",line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0],line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]))
-				except:
+				if 0 <= 1 < len(line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)):
 					try:
-						line=line.replace("$getServerVar"+bot._style[0]+line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],bot._db.get("server",line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0],str(guild.id)))
-					except:
-						break
-		while "$getUserVar"+bot._style[0] in line:
-			if nowloop==line:
-				break
-			else:
-				nowloop=line
-				try:
-					line=line.replace("$getUserVar"+bot._style[0]+line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],bot._db.get("user",line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0],line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1], line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[2]))
-				except:
+						line=line.replace("$getServerVar"+bot._style[0]+line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],str(bot._db.get(line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0],"servers",["id",line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]])))
+					except Exception as e:
+						line=line.replace("$getServerVar"+bot._style[0]+line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],"none")
+				else:
 					try:
-						line=line.replace("$getUserVar"+bot._style[0]+line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],bot._db.get("user",line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0],line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1], str(guild.id)))
+						line=line.replace("$getServerVar"+bot._style[0]+line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],str(bot._db.get(line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0],"servers",["id",str(guild.id)])))
 					except:
-						try:
-							line=line.replace("$getUserVar"+bot._style[0]+line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],bot._db.get("user",line.split("$getUserVar"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0],str(author.id), str(guild.id)))
-						except:
-							break
+						line=line.replace("$getServerVar"+bot._style[0]+line.split("$getServerVar"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],"none")
 		return line
 	async def replaces(line, message, guild, content, msg, vars, timerep, author):
 		nowloop=""
@@ -623,38 +593,51 @@ def _start(client, bot):
 			else:
 				nowloop=line
 				try:
-					top={}
-					topos=1
-					topstr=""
-					if line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0]=="user":
-						data=bot._db.data[line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0]][line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1].split("&")[1]]
-					else:
-						data=bot._db.data[line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0]]
-					for u in data:
+					if line.split('$leaderboard'+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0]=="server":
 						try:
-							top[str(u)]=data[u][line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1].split("&")[0]]
-							topos+=1
+							top = bot._db._cursor.execute(f"SELECT id, {line.split('$leaderboard'+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]} from servers ORDER BY {line.split('$leaderboard'+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]} + 0").fetchall()
 						except:
-							pass
-					top=sorted(top.items(), key=lambda x: x[1], reverse=True)
+							top = bot._db._cursor.execute(f"SELECT id, {line.split('$leaderboard'+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]} from servers ORDER BY {line.split('$leaderboard'+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]}").fetchall()
+					elif line.split('$leaderboard'+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0]=="global":
+						try:
+							top = bot._db._cursor.execute(f"SELECT id, {line.split('$leaderboard'+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]} from globals ORDER BY {line.split('$leaderboard'+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]} + 0").fetchall()
+						except:
+							top = bot._db._cursor.execute(f"SELECT id, {line.split('$leaderboard'+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]} from globals ORDER BY {line.split('$leaderboard'+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]}").fetchall()
+					else:
+						line=line.replace("$leaderboard"+bot._style[0]+line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1], "none")
+						continue
 					topos=0
+					tops={}
+					topstr=""
+					for i, u in top:
+						tops[str(i)]=u
+					top=sorted(tops.items(), key=lambda x: x[1], reverse=True)
 					for t, u in top:
 						try:
-							if topos<=int(line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[2]):
+							if topos<int(line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[2]) and int(line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[2])>=0:
 								if line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0]=="server":
 									t = discord.utils.get(client.guilds, id=int(t))
-								else:
+								elif line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0]=="global":
 									t = discord.utils.get(client.get_all_members(), id=int(t))
 								if t:
 									topos+=1
 									topstr+=str(topos)+". "+str(t)+" - "+str(u)+"\n"
+							elif int(line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[2])==-1:
+								if line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0]=="server":
+									t = discord.utils.get(client.guilds, id=int(t))
+								elif line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0]=="global":
+									t = discord.utils.get(client.get_all_members(), id=int(t))
+								if t:
+									topos+=1
+									topstr+=str(topos)+". "+str(t)+" - "+str(u)+"\n"
+							else:
+								break
 						except:
 							pass
 					while len(topstr)>2000:
 						topstr="\n".join(topstr.split("\n")[:-2])
 					line=line.replace("$leaderboard"+bot._style[0]+line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1], str(topstr))
 				except Exception as e:
-					print(e)
 					line=line.replace("$leaderboard"+bot._style[0]+line.split("$leaderboard"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1], "none")
 		return line
 	
@@ -935,6 +918,12 @@ def _start(client, bot):
 										except:
 											pass
 										loopclose = 1
+						elif line.startswith("$botLeave"+bot._style[0]):
+							if line[-1]==bot._style[1]:
+								line=line[len("$botLeave"+bot._style[0]):]
+								line=line[:-1]
+								line=await replaces(line, message, guild, content, msg, vars, timerep, author)
+								await discord.utils.get(client.guilds, id=int(line)).leave()
 						elif line.startswith("$embedReactionPages"+bot._style[0]):
 							if line[-1]==bot._style[1]:
 								line=line[len("$embedReactionPages"+bot._style[0]):]
@@ -1052,7 +1041,7 @@ def _start(client, bot):
 								except:
 									pass
 						elif line.startswith("$varsFile"):
-							await ctx.send(file=discord.File(bot._db.path+"vars.json"))
+							await ctx.send(file=discord.File(bot._path))
 						elif line.startswith("$sendEmbed"+bot._style[0]):
 							if line[-1]==bot._style[1]:
 								line=line[len("$sendEmbed"+bot._style[0]):]
@@ -1079,20 +1068,20 @@ def _start(client, bot):
 								line=line[:-1]
 								line=await replaces(line, message, guild, content, msg, vars, timerep, author)
 								line=line.split(bot._separator)
-								try:
-									bot._db.set("server",line[0],line[1],line[2])
-								except:
-									bot._db.set("server",line[0],line[1],str(guild.id))
+								if 0 <= 2 < len(line):
+									bot._db.set([line[0],line[1]],"servers",where=["id",line[2]])
+								else:
+									bot._db.set([line[0],line[1]],"servers",where=["id",str(guild.id)])
 						elif line.startswith("$setVar"+bot._style[0]):
 							if line[-1]==bot._style[1]:
 								line=line[len("$setVar"+bot._style[0]):]
 								line=line[:-1]
 								line=await replaces(line, message, guild, content, msg, vars, timerep, author)
 								line=line.split(bot._separator)
-								try:
-									bot._db.set("global",line[0],line[1],line[2])
-								except:
-									bot._db.set("global",line[0],line[1],str(author.id))
+								if 0 <= 2 < len(line):
+									bot._db.set([line[0],line[1]],"globals",where=["id",line[2]])
+								else:
+									bot._db.set([line[0],line[1]],"globals",where=["id",str(author.id)])
 						elif line.startswith("$setLocalVar"+bot._style[0]):
 							if line[-1]==bot._style[1]:
 								line=line[len("$setLocalVar"+bot._style[0]):]
@@ -1123,19 +1112,6 @@ def _start(client, bot):
 									await client.change_presence(activity=discord.Activity(type=discord.ActivityType.listening, name=line[1]),status=status)
 								if line[0]=="stream":
 									await client.change_presence(activity=discord.Activity(type=discord.ActivityType.streaming, name=line[1]),status=status)
-						elif line.startswith("$setUserVar"+bot._style[0]):
-							if line[-1]==bot._style[1]:
-								line=line[len("$setUserVar"+bot._style[0]):]
-								line=line[:-1]
-								line=await replaces(line, message, guild, content, msg, vars, timerep, author)
-								line=line.split(bot._separator)
-								try:
-									bot._db.set("user",line[0],line[1],line[2],line[3])
-								except:
-									try:
-										bot._db.set("user",line[0],line[1],line[2],str(guild.id))
-									except:
-										bot._db.set("user",line[0],line[1],str(author.id),str(guild.id))
 						elif line.startswith("$addReactions"+bot._style[0]):
 							if line[-1]==bot._style[1]:
 								line=line[len("$addReactions"+bot._style[0]):]
@@ -1265,94 +1241,6 @@ def _start(client, bot):
 								line=line[:-1]
 								line=await replaces(line, message, guild, content, msg, vars, timerep, author)
 								await message.channel.purge(limit=int(line)+1)
-						elif line.startswith("$screen"+bot._style[0]):
-							line=line[len("$screen"+bot._style[0]):]
-							if line[-1]==bot._style[1]:
-								from PIL import Image, ImageDraw, ImageFont, ImageFilter
-								from datetime import datetime
-								line=line[:-1]
-								line=await replaces(line, message, guild, content, msg, vars, timerep, author)
-								member=discord.utils.get(guild.members, id=int(line.split(bot._separator)[0]))
-								font = line.split(bot._separator)[1]
-								line=line[len(line.split(bot._separator)[0]+bot._separator+line.split(bot._separator)[1]+bot._separator):]
-								ns=0
-								for i in range(int((len(line))/49)):
-									i=i+1
-									line = line[:i*49] + "\n" + line[i*49:]
-								colour = {
-									"time": (114, 118, 125),
-									"content": (220, 221, 222)
-								}
-							
-								size = {
-									"title": 20,
-									"time": 13
-								}
-								ns=int((len(line))/49)
-								ns=ns-5
-								if ns<0:
-									ns=0
-								img = Image.new('RGB', (600, int(23*(5+ns))), color = (54,57,63))
-								titlefnt = ImageFont.truetype(font, size["title"])
-								timefnt = ImageFont.truetype(font, size["time"])
-								d = ImageDraw.Draw(img)
-								if member.nick is None:
-									txt = member.name
-								else:
-									txt = member.nick
-								color = member.color.to_rgb()
-								if color == (0, 0, 0):
-									color = (255,255,255)
-								d.text((90, 20), txt, font=titlefnt, fill=color)
-								h, w = d.textsize(txt, font=titlefnt)
-								curtime = datetime.now()
-								time = f"Сегодня, {curtime.hour}:{curtime.minute}"
-								d.text((90+h+10, 25), time, font=timefnt, fill=colour["time"])
-								d.text((90, 25+w), line, font=titlefnt, fill=colour["content"])
-								img.save('img.png')
-								if member.is_avatar_animated():
-									await member.avatar_url_as().save("pfp.gif")
-									f2 = Image.open("pfp.gif")
-								else:
-									await member.avatar_url_as(format="png").save("pfp.png")
-									f2 = Image.open("pfp.png")
-								f1 = Image.open("img.png")
-								f2.thumbnail((50, 55))
-								f2.save("pfp.png")
-							
-								f2 = Image.open("pfp.png").convert("RGB")
-							
-								mask = Image.new("L", f2.size, 0)
-								draw = ImageDraw.Draw(mask)
-								draw.ellipse((0, 0, f2.size[0], f2.size[1]), fill=255)
-								mask = mask.filter(ImageFilter.GaussianBlur(0))
-							
-								result = f2.copy()
-								result.putalpha(mask)
-							
-								result.save('pfp.png')
-							
-								f2 = Image.open("pfp.png")
-							
-								f3 = f1.copy()
-								f3.paste(f2, (20, 20), f2)
-								f3.save("img.png")
-							
-								file = discord.File("img.png")
-								await ctx.send(file=file)
-							
-								try:
-									os.remove("pfp.gif")
-								except:
-									pass
-								try:
-									os.remove("pfp.png")
-								except:
-									pass
-								try:
-									os.remove("img.png")
-								except:
-									pass
 						elif line.startswith("$replay"):
 							restart=True
 							break
@@ -1361,40 +1249,46 @@ def _start(client, bot):
 								print(f"Неизвестная функция {beforeline}")
 					except Exception as e:
 						if bot._debug:
-							raise e
 							print(f"Ошибка в функции {beforeline}")
+							raise e
 				else:
 					go-=1
 			if stop:
 				break
-			bot._db.save()
 
 	@client.event
 	async def on_ready():
-		mems=[]
-		for g in client.guilds:
-			if not str(g.id) in bot._db.data["server"]:
-				bot._db.data["server"][str(g.id)]=bot._db.vars
-			else:
-				for v in bot._db.vars:
-					if not v in bot._db.data["server"][str(g.id)]:
-						bot._db.data["server"][str(g.id)][v]=bot._db.vars[v]
-			if not str(g.id) in bot._db.data["user"]:
-				bot._db.data["user"][str(g.id)]={}
-			for m in g.members:
-				if not str(m.id) in bot._db.data["user"][str(g.id)]:
-					bot._db.data["user"][str(g.id)][str(m.id)]=bot._db.vars
-				else:
-					for v in bot._db.vars:
-						if not v in bot._db.data["user"][str(g.id)][str(m.id)]:
-							bot._db.data["user"][str(g.id)][str(m.id)][v]=bot._db.vars[v]
-				if not str(m.id) in bot._db.data["global"]:
-					bot._db.data["global"][str(m.id)]=bot._db.vars
-				else:
-					for v in bot._db.vars:
-						if not v in bot._db.data["global"][str(m.id)]:
-							bot._db.data["global"][str(m.id)][v]=bot._db.vars[v]
-		bot._db.save()
+		adds=""
+		for v in bot._vars:
+			if v!="id":
+				adds+=f",'{bot._vars[v]}'"
+		for guild in client.guilds:
+			bot._vars["id"]=f'{guild.id}'
+			try:
+				if bot._db._cursor.execute(f"SELECT id FROM servers WHERE id = '{guild.id}'").fetchone() is None:
+					bot._db._cursor.execute(f"INSERT INTO servers VALUES('{guild.id}'{adds})")
+			except Exception as e:
+				pass
+			for var in bot._vars:
+				try:
+					if bot._db._cursor.execute(f"SELECT {var} FROM servers WHERE id = '{guild.id}'").fetchone()[0] is None:
+						bot._db._cursor.execute(f'UPDATE servers SET {var}="{bot._vars[var]}" WHERE id="{guild.id}"')
+				except Exception as e:
+					pass
+			for member in guild.members:
+				bot._vars["id"]=f'{member.id}'
+				try:
+					if bot._db._cursor.execute(f"SELECT id FROM globals WHERE id = '{member.id}'").fetchone() is None:
+						bot._db._cursor.execute(f"INSERT INTO globals VALUES('{member.id}'{adds})")
+				except Exception as e:
+					pass
+				for var in bot._vars:
+					try:
+						if bot._db._cursor.execute(f"SELECT {var} FROM globals WHERE id = '{member.id}'").fetchone()[0] is None:
+							bot._db._cursor.execute(f'UPDATE globals SET {var}="{bot._vars[var]}" WHERE id="{member.id}"')
+					except Exception as e:
+						pass
+		bot._db._conn.commit()
 		try:
 			await use("", "botReady", "", "event")
 		except Exception as e:
